#
# spec file for package python-executing
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%{?sle15_python_module_pythons}
Name:           python-executing%{psuffix}
Version:        2.2.0
Release:        1.1
Summary:        Get the currently executing AST node of a frame, and other information
License:        MIT
URL:            https://github.com/alexmojaki/executing
Source:         https://files.pythonhosted.org/packages/source/e/executing/executing-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm >= 4.0.0}
BuildRequires:  %{python_module toml}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module asttokens}
%if 0%{?suse_version} > 1600
BuildRequires:  %{python_module ipython}
%endif
BuildRequires:  %{python_module littleutils}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module rich}
%endif
%python_subpackages

%description
Get the currently executing AST node of a frame, and other information

%prep
%autosetup -p1 -n executing-%{version}

%build
%if %{without test}
%pyproject_wheel
%endif

%install
%if %{without test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%check
%if %{with test}

# Don't have ipython build requirement in Leap
%if 0%{?suse_version} <= 1600
%pytest -k "not test_ipython"
%else
%pytest
%endif

%endif

%if %{without test}
%files %{python_files}
%doc README.md
%license LICENSE.txt
%{python_sitelib}/executing
%{python_sitelib}/executing-%{version}.dist-info
%endif

%changelog
* Mon Mar 10 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.2.0
  * fix: backward compatibility fix for changed source positions in 3.12.6 (#85)
  * fix: handle changed positions for __exit__ of ast.With
  * update and fix table of contents link, 'libraries' → 'projects' (#93)
  * fix: check for pytest compatibility (#94)
- Drop new-python-312.patch, merged upstream
- Drop pytest.patch, merged upstream
* Fri Jan 17 2025 Markéta Machová <mmachova@suse.com>
- Add pytest.patch to fix compatibility with new pytest
* Wed Oct 23 2024 Daniel Garcia <daniel.garcia@suse.com>
- Remove ipython dependency for Leap
* Thu Sep 26 2024 Matej Cepl <mcepl@cepl.eu>
- Split test run into separate build using _multibuild.
* Fri Sep 20 2024 Matej Cepl <mcepl@cepl.eu>
- The test suite has to be run with pytest, unittest is not enough
- Add missing BuildRequires: ipython
* Wed Sep 18 2024 Markéta Machová <mmachova@suse.com>
- Add new-python-312.patch to fix build with recent Python 3.12 release
* Tue Sep 10 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.1.0
  * Add many_calls tests to EXECUTING_SLOW_TESTS (#78)
  * fix: backward compatibility fix for changed source positions in 3.12.5 (#82) (#83)
  * fix(3.13): show_caches is deprecated
  * fix(3.13): added new rules to the verification
  * build(3.13): added 3.13 to ci workflow
  * fix(3.13): fixed typing errors
  * fix(3.13): handle STORE_FAST_STORE_FAST and similar instructions as known issues
  * fix(3.13): loading of __class__ is mapped to the last element of the class
  * fix(3.13): handle CALL_KW like method calls which are only located by the end position
  * fix(3.13): a lambda can also have nonlocal variables
  * fix(3.13): a async function can also have nonlocal variables
  * fix(3.13): COMPARE_OP maps always to ast.Compare
  * fix(3.13): a type variable can also have nonlocal variables
  * test(3.13): handle optimization of `not not x`
  * test: fixed tests for 3.13.0b1
  * fix: allow to LOAD_FAST variables for TypeVars
  * fix: skip files with raise an recursion error in 3.13,
    because the recursion limit has no effect
  * test(3.13): added sample_results
  * test: skip module tests for now
  * refactor: review changes
  * fix: handle __firstlineno__
  * fix: removed unused verification
  * doc: review changes
  * Catch exception if node is in unexpected statement (#84)
  * test: optimized test preformance by moving deadcode check to the end (#89)
  * add 3.13 to setup.cfg classifiers
- Drop support-new-python-3.12.patch, merged upstream
* Mon Aug 26 2024 Steve Kowalik <steven.kowalik@suse.com>
- Switch to autosetup macro.
- Add patch support-new-python-3.12.patch:
  * Support Python 3.13 (and backported to 3.12.5) AST changes for For.
* Tue Nov  7 2023 Dirk Müller <dmueller@suse.com>
- update to 2.0.1:
  * fix: self.fail() is only available in TestCase classes
  * fix: mark expressions which can be evaluated at compile time
    as deadcode
  * fix: implemented DELETE_DEREF
  * feat: 3.12 support for the PositionNodeFinder
  * feat: support LOAD_CONST
  * test: verify exception generation for asserts >= python 3.11.2
  * test: skip test of module_files for the SentinelNodeFinder
  * test: do not check qualnames for files with syntax errors
  * fix: handle List/Set/DictComp inlining
  * fix: handle super optimization
  * fix: type parameter related things
  * fix: f-string
  * fix: disabled type checking for 3.12
  * test: added test results for 3.12
  * fix: workaround for a bug in six
  * remove python2 code
  * feat: support for __iter__
  * feat: support for __next__
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Fri Dec  2 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 1.2.0
  Merge pull request #56 from alexmojaki/init_tokens
    Use new asttokens.ASTText
- Update to 1.1.1
  tox is breaking weirdly with too much parallelism
- Update to 1.1.0
  3.11 in setup.cfg
- Update to 1.0.0
  Merge pull request #46 from alexmojaki/checkcache
    Always check linecache
- Update to 0.10.0
  Merge pull request #45 from alexmojaki/reload
    Clear caches when modules are reloaded
- Update to 0.9.1
  Merge pull request #41 from alexmojaki/node_linenos
    Extract node_linenos to account for end_lineno and use in assert_linenos
- Update to 0.9.0
  * Merge pull request #38 from alexmojaki/pwwang/master
    Support STORE_ATTR and STORE_SUBSCR
* Sun Mar 27 2022 Dirk Müller <dmueller@suse.com>
- update to 0.8.3:
  * handle new iphython cell code names
  * link to futurecoder
* Thu Dec  2 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Skip python 3.6 since python-asttokens dropped it
* Tue Nov  2 2021 pgajdos@suse.com
- version update to 0.8.2
  * no upstream changelog
- %%check: use %%pyunittest rpm macro
* Wed Dec  2 2020 ecsos <ecsos@opensuse.org>
- Update to 0.5.3
  - Handle pypy saying the current instruction is an extended arg
- Changes from 0.5.2
  - Convert path to string before checking filename cache
- Changes from 0.5.1
  - Get top level statement containing IPython node
- Changes from 0.5.0
  - Also cache Source objects by contents (lines)
- Changes from 0.4.4
  - Move packaging metadata into setup.cfg
- Changes from 0.4.3
  - Bump to 0.4.3
* Wed Mar 11 2020 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v0.4.2
